@@ -24,13 +24,14 @@ def trim_from_source(source: str, artist: Optional[str], title: Optional[str],
             raise RuntimeError(f'unrecognized source: {source}')
 
 
-def trim_url(url: str, artist: Optional[str], title: Optional[str],
+def trim_url(url: str, user_artist: Optional[str], user_title: Optional[str],
              no_trim: bool, no_fade: bool, no_normalize: bool,
              trim_start: Optional[float] = None, trim_end: Optional[float] = None, gain: Optional[float] = None):
     with wrap_context('url song'):
         yt_artist, yt_title = extract_youtube_artist_title(url)
-        artist = artist or enter_or_default('Artist', default=yt_artist)
-        title = title or enter_or_default('Title', default=yt_title)
+        info('artist & title extracted from youtube page', artist=yt_artist, title=yt_title)
+        artist = user_artist or enter_or_default('Artist', default=yt_artist)
+        title = user_title or enter_or_default('Title', default=yt_title)
 
         mp3_file = download_from_youtube(url)
         mp3_file = rename_song(mp3_file, artist, title)
@@ -40,15 +41,15 @@ def trim_url(url: str, artist: Optional[str], title: Optional[str],
         info('song saved', mp3_file=mp3_file)
 
 
-def trim_mp3(file: str, artist: Optional[str], title: Optional[str],
+def trim_mp3(file: str, user_artist: Optional[str], user_title: Optional[str],
              no_trim: bool, no_fade: bool, no_normalize: bool,
              trim_start: Optional[float] = None, trim_end: Optional[float] = None, gain: Optional[float] = None):
     with wrap_context('mp3 song'):
         assert os.path.isfile(file), 'input file should exist'
 
         tag_artist, tag_title = read_mp3_artist_title(file)
-        artist = artist or tag_artist or input('Artist: ')
-        title = title or tag_title or input('Title: ')
+        artist = user_artist or tag_artist or enter_or_default('Artist')
+        title = user_title or tag_title or enter_or_default('Title')
 
         mp3_file = rename_song(file, artist, title)
         normalize_song(mp3_file, no_trim, no_fade, no_normalize, trim_start, trim_end, gain)
